@@ -47,7 +47,7 @@ getRemoteFile ()
   # requires $wgetParams and $tmpdir to be defined (above)
   getRemoteFileReturn=""
   grfURL="$1"
-  output=`mktemp --tmpdir=${tmpdir} getRemoteFile.XXXXXX`
+  output=`mktemp -p ${tmpdir} getRemoteFile.XXXXXX`
   if [[ ! `wget ${wgetParams} ${grfURL} -O ${output} 2>&1 | egrep "ERROR 404"` ]]; then # file downloaded
     getRemoteFileReturn=${output}
     # cat ${getRemoteFileReturn}
